#
# spec file for package python-h5netcdf
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-h5netcdf
Version:        1.3.0
Release:        1.8
Summary:        A Python library to use netCDF4 files via h5py
License:        BSD-3-Clause
URL:            https://github.com/h5netcdf/h5netcdf
Source:         https://files.pythonhosted.org/packages/source/h/h5netcdf/h5netcdf-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 42}
BuildRequires:  %{python_module setuptools_scm >= 7}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-h5py
Requires:       python-packaging
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module h5py}
BuildRequires:  %{python_module netCDF4}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A Python interface for the netCDF4 file-format that reads and writes
local or remote HDF5 files directly via h5py or h5pyd, without
relying on the Unidata netCDF library.

%prep
%autosetup -p1 -n h5netcdf-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -rs

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/h5netcdf
%{python_sitelib}/h5netcdf-%{version}.dist-info

%changelog
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.0:
  * Add ros3 support by checking `driver`-kwarg.
* Sun Sep 10 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.2.0
  * MNT: Remove h5py2 compatibility code by @kmuehlbauer in #194
  * FIX: raise early for mismatched object string by @kmuehlbauer
    in #213
  * Add simple test to ensure that the shape is stored in the
    coordinates by @hmaarrfk in #199
* Sat Jan  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.0:
  * Rework adding _FillValue-attribute, add tests.
  * Add special add_phony method for creating phony dimensions, add test.
  * Rewrite _unlabeled_dimension_mix (labeled/unlabeled), add tests.
  * Add default netcdf fillvalues, pad only if necessary, adapt tests.
  * Fix regression in padding algorithm, add test.
  * Set ``track_order=True`` by default in created files if h5py 3.7.0 or
  greater is detected to help compatibility with netCDF4-c programs.
* Tue Aug  2 2022 Matej Cepl <mcepl@suse.com>
- Update to 1.0.2:
  - Adapt boolean indexing as h5py 3.7.0
  - Fix several tests to work with new h5py 3.7.0
* Fri Jul 29 2022 Matej Cepl <mcepl@suse.com>
- Update to 1.0.1:
  - Fix failing tests when using netCDF4 4.9.0.
  - Add HSDS pytest-fixture, make tests work with h5ypd. By
    Aleksandar Jelenak.
  - Remove _NCProperties from existing file if writing invalid
    netcdf features. Warn users if .nc file extension is used
    writing invalid netcdf features. By Kai Mühlbauer.
  - Remove deprecated code (eg. remove deprecated code (eg.
    handling mode, chunking_heuristics, decode_vlen_strings),
    adapt LICENSE/AUTHOR.txt, prepare repository for release
    1.0. By Kai Mühlbauer.
  - Add documentation to h5netcdf, merging current available
    documentation available as .rst-files, in the repo-wiki
    and new API-docs into one document using sphinx-doc and
    sphinx-book-theme. By Kai Mühlbauer.
  - Directly return non-string Empty-type attributes as empty
    numpy-ndarray. By Kai Mühlbauer.
  - Add chunking_heuristic keyword and custom heuristic
    chunking_heuristic="h5netcdf" with better handling of
    unlimited dimensions. By Dion Häfner.
  - Return group name instead of full group path for legacy
    API. By Kai Mühlbauer.
  - Add endian keyword argument
    legacyapi.Dataset.createVariable. By Kai Mühlbauer.
  - Resize Dimensions when writing to variables (legacy API
    only), return padded arrays. By Kai Mühlbauer.
  - Allow 1D boolean indexers in legacy API. By Kai Mühlbauer.
  - Revert order tracking by default to avoid a bug in h5py
    (Closes Issue #136). By Mark Harfouche.
  - Implement Dimension-class. By Kai Mühlbauer.
  - Return items from 0-dim and one-element 1-dim array
    attributes. Return multi-element attributes as lists. Return
    string attributes as Python strings decoded from their
    respective encoding (utf-8, ascii). By Kai Mühlbauer.
  - Assign dimensions at creation time, instead of at sync/flush
    (file-close). By Kai Mühlbauer.
  - Create/attach dimension scales on the fly, instead of at
    sync/flush (file-close). By Kai Mühlbauer.
  - Ensure order tracking is true for newly created netcdf4 files
    as required by the netcdf4 standard. This enables files
    created by h5netcdf to be appended to by netCDF4 library
    users (Closes Issue #128). By Mark Harfouche.
  - Added FutureWarning to use mode='r' as default when opening
    files. By Ryan Grout.
  - Moved handling of _nc4_non_coord_ to
    h5netcdf.BaseVariable. By Kai Mühlbauer.
  - Write _NCProperties when overwriting existing files. By Kai
    Mühlbauer.
  - Create/Attach dimension scales on append (mode="r+") By Kai
    Mühlbauer.
  - Create/Attach/Detach dimension scales only if necessary. By
    Kai Mühlbauer.
  - Switch warning into error when using invalid netCDF
    features. By Kai Mühlbauer.
  - Avoid circular references to objects referencing h5py
    objects. By Tom Augspurger.
  - Included h5pyd.Dataset objects as netCDF variables. By
    Aleksandar Jelenak.
  - Added automatic PyPI upload on creation of github release.
  - Moved Changelog to CHANGELOG.rst.
  - Updated decode_vlen_strings FutureWarning.
  - Support for h5py.Empty strings. By Kai Mühlbauer.
* Fri Feb 19 2021 andy great <andythe_great@pm.me>
- Skip python36 because python-numpy does not support it.
- Remove h5netcdf-pr82-h5py-strings.patch, fixed.
- Update to version 0.10.0.
  * Replaced ``decode_strings`` with ``decode_vlen_strings``.
- Update to version 0.9.0.
  * Support for ``decode_strings``, to restore old behavior with h5py 3.
* Fri Jan 29 2021 Ben Greiner <code@bnavigator.de>
- Add h5netcdf-pr82-h5py-strings.patch for compatibility with
  h5py >= 3.0 gh#h5netcdf/h5netcdf#82
* Sun Jan  3 2021 Jason Craig <os-dev@jacraig.com>
- Update to 0.8.1
  * Fix h5py deprecation warning in test suite.
* Tue Jun  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- NO reason to restrict to pytest4, tests pass with pytest5
* Mon Feb 10 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.8.0
  * Support for reading Datasets with missing dimension scales.
  * Fixed a bug where Datatype objects were treated as Datasets.
  * Fixed several issues with upstream deprecations.
* Tue Dec  3 2019 Todd R <toddrme2178@gmail.com>
- Initial version
